# tree-sitter-surrealql

[![CI][ci]](https://github.com/ce11an/tree-sitter-surrealql/actions/workflows/ci.yml)
[![crates][crates]](https://crates.io/crates/tree-sitter-surrealql)
[![pypi][pypi]](https://pypi.org/project/tree-sitter-surrealql/)

SurrealQL grammar for [tree-sitter][].

## Installation

### [cargo](https://crates.io/crates/tree-sitter-surrealql)

```sh
cargo add tree-sitter-surrealql
```

### [pip](https://pypi.org/project/tree-sitter-surrealql)

```bash
pip install tree-sitter-surrealql
```

## Features
Please check the [examples](examples) directory for a complete list of features.

## References
- [SurrealDB](https://surrealdb.com/docs/surrealdb)

[ci]: https://img.shields.io/github/actions/workflow/status/ce11an/tree-sitter-surrealql/ci.yml?logo=github&label=CI
[tree-sitter]: https://github.com/tree-sitter/tree-sitter
[crates]: https://img.shields.io/crates/v/tree-sitter-surrealql?logo=rust
[pypi]: https://img.shields.io/pypi/v/tree-sitter-surrealql?logo=pypi&logoColor=ffd242
